@@ -49,7 +49,7 @@ Get_AdmUnNames <- function(Year = 2023, date = "01_01", autoAbort = FALSE){
       readr::read_delim(url, delim = ";", show_col_types = FALSE)
     }, error = function(e){
       message("Cannot read the file; ", 10 - attempt,
-              " attempts left. If the problem persists, please contact the mantainer.\n")
+              " attempts left. If the problem persists, please contact the maintainer.\n")
       return(NULL)
     })
     attempt <- attempt + 1
